@@ -1,16 +1,21 @@
 package Pod::Weaver::Plugin::EnsurePod5;
-{
-  $Pod::Weaver::Plugin::EnsurePod5::VERSION = '4.005';
-}
+# ABSTRACT: ensure that the Pod5 translator has been run on this document
+$Pod::Weaver::Plugin::EnsurePod5::VERSION = '4.007';
 use Moose;
 with 'Pod::Weaver::Role::Preparer';
-# ABSTRACT: ensure that the Pod5 translator has been run on this document
 
 use namespace::autoclean;
 use Moose::Autobox;
 
 use Pod::Elemental::Transformer::Pod5;
 
+#pod =head1 OVERVIEW
+#pod
+#pod This plugin is very, very simple:  it runs the Pod5 transformer on the input
+#pod document and removes any leftover whitespace-only Nonpod elements.  If
+#pod non-whitespace-only Nonpod elements are found, an exception is raised.
+#pod
+#pod =cut
 
 sub _strip_nonpod {
   my ($self, $node) = @_;
@@ -42,7 +47,7 @@ sub prepare_input {
   return;
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -57,7 +62,7 @@ Pod::Weaver::Plugin::EnsurePod5 - ensure that the Pod5 translator has been run o
 
 =head1 VERSION
 
-version 4.005
+version 4.007
 
 =head1 OVERVIEW
 
@@ -71,7 +76,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
