@@ -1,10 +1,8 @@
 package Pod::Weaver::Plugin::H1Nester;
-{
-  $Pod::Weaver::Plugin::H1Nester::VERSION = '4.005';
-}
+# ABSTRACT: structure the input pod document into head1-grouped sections
+$Pod::Weaver::Plugin::H1Nester::VERSION = '4.007';
 use Moose;
 with 'Pod::Weaver::Role::Transformer';
-# ABSTRACT: structure the input pod document into head1-grouped sections
 
 use namespace::autoclean;
 use Moose::Autobox;
@@ -12,6 +10,13 @@ use Moose::Autobox;
 use Pod::Elemental::Selectors -all;
 use Pod::Elemental::Transformer::Nester;
 
+#pod =head1 OVERVIEW
+#pod
+#pod This plugin is very, very simple:  it uses the
+#pod L<Pod::Elemental::Transformer::Nester> to restructure the document under its
+#pod C<=head1> elements.
+#pod
+#pod =cut
 
 sub transform_document {
   my ($self, $document) = @_;
@@ -29,7 +34,7 @@ sub transform_document {
   return;
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -44,7 +49,7 @@ Pod::Weaver::Plugin::H1Nester - structure the input pod document into head1-grou
 
 =head1 VERSION
 
-version 4.005
+version 4.007
 
 =head1 OVERVIEW
 
@@ -58,7 +63,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
