@@ -1,14 +1,35 @@
 package Pod::Weaver::Section::Legal;
-{
-  $Pod::Weaver::Section::Legal::VERSION = '4.005';
-}
+# ABSTRACT: a section for the copyright and license
+$Pod::Weaver::Section::Legal::VERSION = '4.007';
 use Moose;
 with 'Pod::Weaver::Role::Section';
-# ABSTRACT: a section for the copyright and license
 
 use Moose::Autobox;
 
+#pod =head1 OVERVIEW
+#pod
+#pod This section plugin will produce a hunk of Pod giving the copyright and license
+#pod information for the document, like this:
+#pod
+#pod   =head1 COPYRIGHT AND LICENSE
+#pod
+#pod   This document is copyright (C) 1991, Ricardo Signes.
+#pod
+#pod   This document is available under the blah blah blah.
+#pod
+#pod This plugin will do nothing if no C<license> input parameter is available.  The
+#pod C<license> is expected to be a L<Software::License> object.
+#pod
+#pod =cut
 
+#pod =attr license_file
+#pod
+#pod Specify the name of the license file and an extra line of text will be added
+#pod telling users to check the file for the full text of the license.
+#pod
+#pod Defaults to none.
+#pod
+#pod =cut
 
 has license_file => (
   is => 'ro',
@@ -40,7 +61,7 @@ sub weave_section {
   );
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -55,7 +76,7 @@ Pod::Weaver::Section::Legal - a section for the copyright and license
 
 =head1 VERSION
 
-version 4.005
+version 4.007
 
 =head1 OVERVIEW
 
@@ -86,7 +107,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
