@@ -1,14 +1,32 @@
 package Pod::Weaver::Section::Name;
-{
-  $Pod::Weaver::Section::Name::VERSION = '4.005';
-}
+# ABSTRACT: add a NAME section with abstract (for your Perl module)
+$Pod::Weaver::Section::Name::VERSION = '4.007';
 use Moose;
 with 'Pod::Weaver::Role::Section';
 with 'Pod::Weaver::Role::StringFromComment';
-# ABSTRACT: add a NAME section with abstract (for your Perl module)
 
 use Moose::Autobox;
 
+#pod =head1 OVERVIEW
+#pod
+#pod This section plugin will produce a hunk of Pod giving the name of the document
+#pod as well as an abstract, like this:
+#pod
+#pod   =head1 NAME
+#pod
+#pod   Some::Document - a document for some
+#pod
+#pod It will determine the name and abstract by inspecting the C<ppi_document> which
+#pod must be given.  It looks for comments in the form:
+#pod
+#pod
+#pod   # ABSTRACT: a document for some
+#pod   # PODNAME: Some::Package::Name
+#pod
+#pod If no C<PODNAME> comment is present, but a package declaration can be found,
+#pod the package name will be used as the document name.
+#pod
+#pod =cut
 
 use Pod::Elemental::Element::Pod5::Command;
 use Pod::Elemental::Element::Pod5::Ordinary;
@@ -80,6 +98,7 @@ sub weave_section {
   $document->children->push($name_para);
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -94,7 +113,7 @@ Pod::Weaver::Section::Name - add a NAME section with abstract (for your Perl mod
 
 =head1 VERSION
 
-version 4.005
+version 4.007
 
 =head1 OVERVIEW
 
@@ -120,7 +139,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
